Module vec

Module vec 

Growable contiguous array with an explicit allocator.

ExVec<T> is a dynamically-sized list that stores its elements in a heap-allocated buffer obtained from a user-supplied Allocator. It is functionally analogous to std::vec::Vec but never touches a global allocator.

Growth Policy

The initial capacity is 4. Every time the buffer is exhausted, the capacity is doubled (new_cap = old_cap * 2). Data is migrated to the new buffer using SIMD-accelerated copy_bytes.

SIMD Extensions (ExVec<u8>)

When T = u8, additional methods are available: simd_fill, find_byte, for_each_byte_match, extend_filled.

Structs

ExVec
A contiguous growable array backed by an explicit allocator.